@@ -26,4 +26,9 @@ sub hello_get_with_params :get(hello_world) :params(test => 'okay') {
 	$_[1]->response->hello = "world 3";
 }
 
+sub redirect :any {
+	my ($self, $t) = @_;
+	$t->redirect('https://lnation.org');
+}
+
 1;
